import 'package:flutter/material.dart';
import 'package:unify_api/unify.dart';
import 'package:unify_api_example/common/index.dart';
import 'package:unify_api_example/utils/index.dart';

class AccountInfoExample extends StatefulWidget {
  final UnifyClient client;

  const AccountInfoExample({Key key, this.client}) : super(key: key);

  @override
  _AccountInfoExampleState createState() => _AccountInfoExampleState();
}

class _AccountInfoExampleState extends State<AccountInfoExample> {
  AccountInfo _details;
  List<Text> impUsers = [];
  List<Widget> alertWidgets = [];
  List<InquiryAlert> alerts = [];
  @override
  void initState() {
    widget.client.listInquiryAlerts(rows: 10, page: 1).then((value) {
      setState(() {
        alerts = value;
        for (var alert in alerts){
          alertWidgets.add(
            ListTile(
              title: Text('${alert.firstName}, ${alert.lastName}'),
              subtitle: Text('${alert.loanNumber}'),
              trailing: JsonButton(json: alert?.json),
            )
          );
        }
      });
    });
    widget.client.getInfo().then((details) {
      setState(() {
        _details = details;
      });
    });
    widget.client.getImpersinationList().then((value) {
      setState(() {
        for(var item in value){
          impUsers.add(Text(item.name));
        }
      });
    });
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text("Account Details"),
        actions: <Widget>[
          JsonButton(json: _details?.json),
        ],
      ),
      body: Builder(
        builder: (BuildContext context) {
          if (_details == null)
            return Center(child: CircularProgressIndicator());
          return ListView(
            children: <Widget>[
              ListTile(
                title: Text("Full Name"),
                subtitle: Text(_details.fullName),
              ),
              ListTile(
                title: Text("Video Enabled"),
                subtitle: Text(_details.videoEnabled.toString()),
              ),
              ListTile(
                title: Text("Email"),
                subtitle: Text(_details.email),
              ),
              ListTile(
                title: Text("Primary Phone"),
                subtitle: Text(_details.primaryPhone.toString()),
              ),
              ListTile(
                title: Text("Secondary Phone"),
                subtitle: Text(_details.secondaryPhone.toString()),
              ),
              ListTile(
                title: Text("Access Token"),
                subtitle: TextFormField(
                    initialValue: _details.client.token.accessToken),
              ),
              ListTile(
                title: Text("Unify Alerts"),
                subtitle: Text("Tap To View"),
                onTap: () async {
                  var items = await widget.client.listUnifyAlerts() ?? [];

                  List<Widget> _children = [];
                  _children = items
                      .map((i) => ListTile(
                            title: Text(i.type),
                            subtitle: Text(i.date.toString()),
                            trailing: JsonButton(json: i?.json),
                          ))
                      .toList();
                  showList(context, _children);
                },
              ),
              ListTile(
                title: Text('Get Tasks'),
                subtitle: Text('Taps to view'),
                onTap: () async {
                  var events = await widget.client.listTasksAll(date: DateTime.now(), month: 10);
                  print('done');
                },
              ),
              ExpansionTile(
                title: Text('Impersination'),
                subtitle: Text('view users'),
                children: impUsers
              ),
              ListTile(
                title: Text('Test get Imp Token'),
                subtitle: Text("press me"),
                onTap: () async {
                  var item = await widget.client.impersinateUser("1145d3eb-1938-481f-89ef-2bfcebfe5331");
                  print(item.accessToken);
                },
              ),
              ExpansionTile(
                title: Text('Inquiry Alerts'),
                subtitle: Text('View Alerts'),
                children: alertWidgets,
              )
            ],
          );
        },
      ),
    );
  }
}
