import 'package:flutter/material.dart';
import 'package:unify_api/unify.dart';
import 'package:unify_api_example/common/index.dart';
import 'package:unify_api_example/utils/index.dart';

class DashboardAlertsExample extends StatelessWidget {
  final UnifyClient client;

  const DashboardAlertsExample({Key key, this.client}) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return Scaffold(
        appBar: AppBar(
          title: const Text('Dashboard Alerts'),
        ),
        body: LayoutBuilder(
          builder: (context, dimens) => GridView.count(
            crossAxisCount: getCrossCount(dimens),
            children: <Widget>[
              GridItem(
                iconData: Icons.people,
                name: "Opportunities",
                details: AlertsListExample(
                  client: client,
                  name: "Opportunities",
                  alerts: client.listOpportunitiyAlerts(),
                ),
              ),
              GridItem(
                iconData: Icons.people,
                name: "Hot Prospects",
                details: AlertsListExample(
                  client: client,
                  alerts: client.listHotProspectAlerts(),
                  name: "Hot Prospects",
                ),
              ),
              GridItem(
                iconData: Icons.people,
                name: "Customer",
                details: AlertsListExample(
                  client: client,
                  alerts: client.listCustomerAlerts(),
                  name: "Customer",
                ),
              ),
              GridItem(
                iconData: Icons.people,
                name: "Pipeline",
                details: AlertsListExample(
                  client: client,
                  alerts: client.listPipelineAlerts(),
                  name: "Pipeline",
                ),
              ),
              GridItem(
                iconData: Icons.people_outline,
                name: "Partners",
                details: PartnerAlertsListExample(
                  client: client,
                  alerts: client.listDashboardPartners(),
                  name: "Partners",
                ),
              ),
            ],
          ),
        ));
  }
}

class AlertsListExample extends StatefulWidget {
  final UnifyClient client;
  final Future<List<DashboardAlert>> alerts;
  final String name;

  const AlertsListExample({
    Key key,
    @required this.client,
    @required this.alerts,
    @required this.name,
  }) : super(key: key);
  @override
  _AlertsListExampleState createState() => _AlertsListExampleState();
}

class _AlertsListExampleState extends State<AlertsListExample> {
  List<DashboardAlert> _items;

  @override
  void initState() {
    widget.alerts.then((items) {
      setState(() {
        _items = items;
      });
    });
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(widget?.name ?? ""),
      ),
      body: Builder(
        builder: (BuildContext context) {
          if (_items == null) return Center(child: CircularProgressIndicator());
          if (_items.isEmpty) return Center(child: Text("No Alerts Found"));
          return ListView.builder(
            itemBuilder: (BuildContext context, int index) {
              final i = _items[index];
              return ListTile(
                title: Text(i.displayName),
                subtitle: Text(i.alertType),
                trailing: JsonButton(json: i?.json),
              );
            },
            itemCount: _items?.length ?? 0,
          );
        },
      ),
    );
  }
}

class PartnerAlertsListExample extends StatefulWidget {
  final UnifyClient client;
  final Future<List<DashboardPartners>> alerts;
  final String name;

  const PartnerAlertsListExample({
    Key key,
    @required this.client,
    @required this.alerts,
    @required this.name,
  }) : super(key: key);
  @override
  _PartnerAlertsListExampleState createState() =>
      _PartnerAlertsListExampleState();
}

class _PartnerAlertsListExampleState extends State<PartnerAlertsListExample> {
  List<DashboardPartners> _items;

  @override
  void initState() {
    widget.alerts.then((items) {
      setState(() {
        _items = items;
      });
    });
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(widget?.name ?? ""),
      ),
      body: Builder(
        builder: (BuildContext context) {
          if (_items == null) return Center(child: CircularProgressIndicator());
          if (_items.isEmpty) return Center(child: Text("No Partners Found"));
          return ListView.builder(
            itemBuilder: (BuildContext context, int index) {
              final i = _items[index];
              return ListTile(
                title: Text(i.displayName),
                subtitle: Text(i.alertType),
                trailing: JsonButton(json: i?.json),
              );
            },
            itemCount: _items?.length ?? 0,
          );
        },
      ),
    );
  }
}
