import 'package:flutter/material.dart';
import 'package:unify_api/unify.dart';
import 'package:unify_api_example/common/index.dart';
import 'package:unify_api_example/utils/index.dart';

class VideoExample extends StatelessWidget {
  final UnifyClient client;

  const VideoExample({Key key, this.client}) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return Scaffold(
        appBar: AppBar(
          title: const Text('Unify Videos'),
        ),
        body: LayoutBuilder(
          builder: (context, dimens) => GridView.count(
            crossAxisCount: getCrossCount(dimens),
            children: <Widget>[
              GridItem(
                iconData: Icons.video_library,
                name: "All Videos",
                details: VideosListExample(
                  client: client,
                  name: "All",
                  videos: client.listVideosAll(),
                ),
              ),
              GridItem(
                iconData: Icons.video_library,
                name: "My Videos",
                details: VideosListExample(
                  client: client,
                  name: "My",
                  videos: client.listVideosMyVideos(),
                ),
              ),
              GridItem(
                  iconData: Icons.video_library,
                  name: "Shared Videos",
                  details: VideosListExample(
                    client: client,
                    name: "Shared",
                    videos: client.listVideosShared(),
                  )),
              GridItem(
                iconData: Icons.video_library,
                name: "Archived Videos",
                details: VideosListExample(
                  client: client,
                  name: "Archived",
                  videos: client.listVideosArchived(),
                ),
              ),
            ],
          ),
        ));
  }
}

class VideosListExample extends StatefulWidget {
  final UnifyClient client;
  final Future<List<Video>> videos;
  final String name;

  const VideosListExample({
    Key key,
    @required this.client,
    @required this.videos,
    @required this.name,
  }) : super(key: key);
  @override
  _VideosListExampleState createState() => _VideosListExampleState();
}

class _VideosListExampleState extends State<VideosListExample> {
  List<Video> _items;

  @override
  void initState() {
    widget.videos.then((items) {
      setState(() {
        _items = items;
      });
    });
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text((widget?.name ?? "") + " Videos"),
      ),
      body: Builder(
        builder: (BuildContext context) {
          if (_items == null) return Center(child: CircularProgressIndicator());
          if (_items.isEmpty) return Center(child: Text("No Videos Found"));
          return ListView.builder(
            itemBuilder: (BuildContext context, int index) {
              final i = _items[index];
              return ListTile(
                title: Text(i.displayName),
                subtitle: Text(i.description),
                trailing: JsonButton(json: i?.json),
                onTap: () {
                  Navigator.push(
                    context,
                    MaterialPageRoute(
                      builder: (BuildContext context) => VideoDetailsExample(
                        video: i.getDetails(),
                      ),
                    ),
                  );
                },
              );
            },
            itemCount: _items?.length ?? 0,
          );
        },
      ),
    );
  }
}

class VideoDetailsExample extends StatefulWidget {
  final Future<VideoDetails> video;

  const VideoDetailsExample({Key key, @required this.video}) : super(key: key);
  @override
  _VideoDetailsExampleState createState() => _VideoDetailsExampleState();
}

class _VideoDetailsExampleState extends State<VideoDetailsExample> {
  VideoDetails _details;
  String _preview, _share;

  @override
  void initState() {
    widget.video.then((details) {
      setState(() {
        _details = details;
      });
    });
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text("Video Details"),
        actions: <Widget>[
          JsonButton(json: _details?.json),
        ],
      ),
      body: Builder(
        builder: (BuildContext context) {
          if (_details == null)
            return Center(child: CircularProgressIndicator());

          return ListView(
            children: <Widget>[
              ListTile(
                title: Container(
                  child:
                      Image.network(_details?.getThumbnail(width: 400) ?? ""),
                ),
              ),
              ListTile(
                title: Text("Name"),
                subtitle: Text(_details?.name ?? ""),
              ),
              ListTile(
                title: Text("Description"),
                subtitle: Text(_details?.description ?? ""),
              ),
              ListTile(
                title: Text("Views"),
                subtitle: Text(_details?.views?.toString() ?? ""),
              ),
              ListTile(
                title: Text("Plays"),
                subtitle: Text(_details?.plays?.toString() ?? ""),
              ),
              ListTile(
                title: Text("Preview URL"),
                subtitle:
                    _preview == null ? Text("Tap to Load") : Text(_preview),
                onTap: () async {
                  var _url = await _details?.preview();
                  setState(() {
                    _preview = _url.toString();
                  });
                },
              ),
              ListTile(
                title: Text("Share URL"),
                subtitle: _share == null ? Text("Tap to Load") : Text(_share),
                onTap: () async {
                  var _url = await _details?.share();
                  setState(() {
                    _share = _url.toString();
                  });
                },
              ),
            ],
          );
        },
      ),
    );
  }
}
