part of unify;

class Loan implements UnifyObject, QueryObject, SortableObject<Loan> {
  Loan(this.client, this.json);

  @override
  final UnifyClient client;

  @override
  final Map<String, dynamic> json;

  String get id => json["loan_id"];
  String get contactId => json["contact_id"];
  String get firstName => json["first_name"];
  String get lastName => json["last_name"];
  String get fullName => "$firstName $lastName".trim();
  String get displayName => "$lastName, $firstName";
  String get cellPhone => json["cell_phone"];
  String get officePhone => json["office_phone"];
  String get homePhone => json["home_phone"];
  DateTime get dateClosed => DateTime.tryParse(json["date_closed"] as String);
  String get loanMilestone => json["loan_milestone"];
  String get loanNumber => json["loan_number"];
  double get loanRate => json["loan_rate"];
  String get email => json["email"];

  // -- Actions --
  Future<LoanDetails> getDetails() {
    return client.getLoanDetails(id);
  }

  Future<List<LoanContact>> listContacts() {
    return client.listLoanContacts(id);
  }

  Future<LoanProgress> getProgress() {
    return client.getLoanStatus(id);
  }

  @override
  bool matchesSearch(String search) {
    if (search == null || search.isEmpty) {
      return true;
    }

    search = search.toLowerCase();

    if (firstName.toLowerCase().contains(search)) {
      return true;
    }
    if (lastName.toLowerCase().contains(search)) {
      return true;
    }
    if (cellPhone.toLowerCase().contains(search)) {
      return true;
    }
    if (homePhone.toLowerCase().contains(search)) {
      return true;
    }
    if (officePhone.toLowerCase().contains(search)) {
      return true;
    }
    if (email.toLowerCase().contains(search)) {
      return true;
    }
    if (dateClosed.toString().toLowerCase().contains(search)) {
      return true;
    }
    if (loanMilestone.toString().toLowerCase().contains(search)) {
      return true;
    }
    if (loanNumber.toString().toLowerCase().contains(search)) {
      return true;
    }
    if (loanRate.toString().toLowerCase().contains(search)) {
      return true;
    }
    return false;
  }

  @override
  List<String> sortFields = [
    "first_name",
    "last_name",
    "cell_phone",
    "office_phone",
    "home_phone",
    "date_closed",
    "loan_number",
    "email",
    "loan_milestone",
    "loan_rate",
  ];

  @override
  int compareTo(Loan object, String sortField, bool sortAscending) {
    int response = 0;
    Loan objectA = sortAscending ? this : object;
    Loan objectB = sortAscending ? object : this;

    switch (sortField) {
      case "first_name":
        response = objectA.firstName.compareTo(objectB.firstName);
        break;
      case "last_name":
        response = objectA.lastName.compareTo(objectB.lastName);
        break;
      case "cell_phone":
        response = objectA.cellPhone.compareTo(objectB.cellPhone);
        break;
      case "office_phone":
        response = objectA.officePhone.compareTo(objectB.officePhone);
        break;
      case "home_phone":
        response = objectA.homePhone.compareTo(objectB.homePhone);
        break;
      case "date_closed":
        response = objectA.dateClosed.compareTo(objectB.dateClosed);
        break;
      case "loan_number":
        response = objectA.loanNumber.compareTo(objectB.loanNumber);
        break;
      case "email":
        response = objectA.email.compareTo(objectB.email);
        break;
      case "loan_milestone":
        response = objectA.loanMilestone.compareTo(objectB.loanMilestone);
        break;
      case "loan_rate":
        response = objectA.loanRate.compareTo(objectB.loanRate);
        break;
    }

    if (response == 0) {
      return objectA.firstName.compareTo(objectB.firstName);
    } else {
      return response;
    }
  }
}
