part of unify;

class MarketingMaterial
    implements UnifyObject, QueryObject, SortableObject<MarketingMaterial> {
  MarketingMaterial(this.client, this.json);

  @override
  final UnifyClient client;

  @override
  final Map<String, dynamic> json;

  String get id => json["id"];

  String get imageUrl => json["image_url"];

  String get name => json["name"];

  String get description => json["description"];

  String get type => json["type"];

  String get category => json["category"];

  String get subCategory => json["sub_category"];

  DateTime get date => DateTime.tryParse(json["week"] as String);

  double get price => json["price"];

  int get mailings => json["mailings"];

  bool get coBrand => json["co_brand"];

  // -- Actions --
  Future<MarketingMaterialDetails> getDetails() {
    return client.getMarketingDetails(id);
  }

  Future<MarketingValidation> validate({
    String partnerId,
    bool sendNow,
    DateTime startDate,
    List<String> contactIds,
    List<String> leadIds,
  }) {
    return client.getMarketingValidation(
      id,
      partnerId: partnerId,
      sendNow: sendNow,
      startDate: startDate,
      contactIds: contactIds,
      leadIds: leadIds,
    );
  }

  Future startCampaign({
    String partnerId,
    bool sendNow,
    DateTime startDate,
    List<String> contactIds,
    List<String> leadIds,
  }) {
    return client.startMarketingCampaign(
      id,
      partnerId: partnerId,
      sendNow: sendNow,
      startDate: startDate,
      contactIds: contactIds,
      leadIds: leadIds,
    );
  }

  Future addToCart({
    String partnerId,
    bool sendNow,
    DateTime startDate,
    List<String> contactIds,
    List<String> leadIds,
  }) {
    return client.addMarketingCampaignToCart(
      id,
      partnerId: partnerId,
      sendNow: sendNow,
      startDate: startDate,
      contactIds: contactIds,
      leadIds: leadIds,
    );
  }

  @override
  List<String> sortFields = [
    "name",
    "description",
    "price",
    "cobrand",
    "mailings",
    "type",
    "category",
    "subcategory",
    "week",
  ];

  @override
  int compareTo(
      MarketingMaterial object, String sortField, bool sortAscending) {
    int response = 0;
    MarketingMaterial objectA = sortAscending ? this : object;
    MarketingMaterial objectB = sortAscending ? object : this;

    switch (sortField) {
      // STARTER: sort switch - do not remove comment
      case "name":
        response = objectA.name.compareTo(objectB.name);
        break;
      case "description":
        response = objectA.description.compareTo(objectB.description);
        break;
      case "price":
        response = objectA.price.compareTo(objectB.price);
        break;
      case "cobrand":
        response =
            objectA.coBrand.toString().compareTo(objectB.coBrand.toString());
        break;
      case "price":
        response = objectA.price.toString().compareTo(objectB.price.toString());
        break;
      case "mailings":
        response =
            objectA.mailings.toString().compareTo(objectB.mailings.toString());
        break;
      case "type":
        response = objectA.type.compareTo(objectB.type);
        break;
      case "subcategory":
        response = objectA.subCategory.compareTo(objectB.subCategory);
        break;
      case "category":
        response = objectA.category.compareTo(objectB.category);
        break;
      case "week":
        response = objectA.date.compareTo(objectB.date);
        break;
    }

    if (response == 0) {
      // STARTER: sort default - do not remove comment
      return objectA.name.compareTo(objectB.name);
    } else {
      return response;
    }
  }

  @override
  bool matchesSearch(String search) {
    if (search == null || search.isEmpty) {
      return true;
    }

    search = search.toLowerCase();

    if (name.toLowerCase().contains(search)) {
      return true;
    }
    if (description.toLowerCase().contains(search)) {
      return true;
    }

    if (category.toLowerCase().contains(search)) {
      return true;
    }
    if (subCategory.toLowerCase().contains(search)) {
      return true;
    }
    if (type.toString().toLowerCase().contains(search)) {
      return true;
    }
    if (price.toString().toLowerCase().contains(search)) {
      return true;
    }
    if (mailings.toString().toLowerCase().contains(search)) {
      return true;
    }
    if (date.toString().toLowerCase().contains(search)) {
      return true;
    }
    if (coBrand.toString().toLowerCase().contains(search)) {
      return true;
    }
    return false;
  }
}
